function [NominalCoherence,FAcoherence] = SIM_FAcohere(u,y,options,Fs,f1,f2)
%   
%   Uses MATLAB's "mscohere" but also provides the capability to take the
%   coherence at a specific frequency area. 
%   
%   Syntax:
%   [NominalCoherence,FAcoherence] = FAcohere(u,y,options,Fs,f1,f2)
%   
%   ### AIROBOTS COAX Small System Identification Toolbox
%
%   Inputs:
%   u       : the measured input
%   y       : the measured output
%   options : structure that contains the coherence options
%           options.Window   = Windowing function and number of samples to
%                              use for each section
%           options.Noverlap = Number of samples by which the sections 
%                              overlap
%           options.NFFT     = FT length which determines the frequencies 
%                              at which the coherence is estimated
%           options.plot     = if == 1 then the coherence is being plot
%   Fs      : Sampling Frequency
%   f1      : Lower Bound of the desired Frequency Area (Hz)
%   f2      : Higher Bound of the desired Frequency Area (Hz)
%
%   Outputs:
%   NominalCoherence    : Structure that contains the information about the
%                         total coherence.
%                       NominalCoherence.coherence  : coherence values
%                       NominalCoherence.freqs      : frequency values
%                       NominalCoherence.meanValue  : coherence mean value
%   FAcoherence         : Structure that contains the information about the
%                         coherence in the specific frequency area.
%                       FAcoherence.coherence       : coherence values
%                       FAcoherence.freqs           : frequency values
%                       FAcoherence.meanValue       : coherence mean value
%
%   Authors:    Kostas Alexis (konstantinos.alexis@mavt.ethz.ch)
%

if((f1>(Fs/2))||(f2>(Fs/2)))
    cprintf('-Error','!!! Cannot proceed: f1,f2 must be less than Fs/2\n');
else

if(f2<f1)
    cprintf('-Error','!!! Cannot proceed: f1 should be less than f2\n');
else
    
if(length(u)~=length(y))
    cprintf('-Error','!!! Cannot proceed: different lengths between input and output\n');
else
    
[coherence, all_freqs] = mscohere(u,y,options.Window,options.Noverlap,options.NFFT,Fs);

cnt = 1;
for i = 1:length(all_freqs)
    if((all_freqs(i)>=f1)&&(all_freqs(i)<=f2))
        coherence_at_spec_freqs(cnt) = coherence(i);
        spec_freqs(cnt) = all_freqs(i);
        cnt = cnt + 1;
    end
end

NominalCoherence.coherence = coherence;
NominalCoherence.freqs = all_freqs;
NominalCoherence.meanValue = sum(coherence)/length(coherence);

FAcoherence.coherence = coherence_at_spec_freqs;
FAcoherence.freqs = spec_freqs;
FAcoherence.meanValue = sum(coherence_at_spec_freqs)/length(coherence_at_spec_freqs);

if(options.plot == 1)
    figure
    plot(all_freqs,coherence);
    hold on
    plot(spec_freqs,coherence_at_spec_freqs,'g');
    xlabel('Frequency (Hz)');
    ylabel('Magnitude');
    grid on
end

end
end
end
end