function [RandomFrqError,Freqs] = rand_freq_error(u,y,options)
%   
%   Random-Error Function based on coherences in the Frequency Domain
%   
%   Syntax:
%   RandomFrqError,Freqs] = rand_freq_error(coherence,freqs,options)
%   
%   ### AIROBOTS COAX Small System Identification Toolbox
%
%   Inputs:
%   coherence   : Coherences vector
%   freqs       : vector that containts the corresponding frequencies
%   options : structure that contains the random-error options
%           options.C_e     : scalar related with the Windowing
%           options.Fs      : sampling frequency
%           options.Window  : Windowing function
%           options.noverlap: no overlap value
%           options.nfft    : nfft value
%           options.plot    : if == 1 plots the Random-Error function
%
%   Outputs:
%   RandomFrqError  : The random error function over the specified
%   frequencies
%   Freqs           : the vector of the specified frequencies
%
%   Authors:    Kostas Alexis (konstantinos.alexis@mavt.ethz.ch)
%

[coherence,freqs] = mscohere(u,y,options.Window,options.noverlap,options.nfft);
nd = length(u)/length(options.Window);
if(isempty(options.Window))
    nd = floor(length(u)/8);
end
Freqs = rad_s2Hz(freqs*options.Fs);

RandomFrqError(1:length(coherence)) = 0;
for i = 1:length(coherence)
    RandomFrqError(i) = options.C_e*sqrt(1-coherence(i))/(sqrt(abs(coherence(i)))*sqrt(2*nd));
end

if(options.plot == 1)
figure;
title('Random-error Function in Frequency Domain');
plot(Freqs,RandomFrqError,'b','LineWidth',2.0);
xlabel('Frequency'); ylabel('Random Frequency Error');
grid on;
end

cprintf('-Blue','Note: Good Random Error should be <=0.1 at your desired frequencies! \n');

end
