function StabTest = ACX_SIM_Check_SS_Stability(ssmodel)
%
%   Syntax:
%   StabTest = ACX_SIM_Check_SS_Stability(ssmodel)
%   
%   Inputs:
%   ssmodel     : A state space model (or ss id_model)
%
%   Outputs:
%   StabTest    : Structure that contains all stability information ->
%       StabTest.eigen.values   : the eigenvalues of matrix A
%       StabTest.eigen.V        : "nobalance" matrix of eigenvectors
%       StabTest.eigen.D        : "nobalance" matrix of eigenvalues
%       StabTest.singular.S     : Singular values of A
%       StabTest.singular.U and  
%       StabTest.singular.V     : unitary matrices such tat A = U*S*V'
%
%   This function will also print out a red message if positive eigenvalues
%   are found (unstable A) and a black message if critically stable poles
%   are found.
%
%   Authors : Kostas Alexis (konstantinos.alexis@mavt.ethz.ch)
%
Amatrix = ssmodel.A;
Bmatrix = ssmodel.B;
% Cmatrix = ssmodel.C;
% Dmatrix = ssmodel.D;

% compute eigenvalues

eigsA = eig(Amatrix);

flag_unstable = 0;
flag_critical = 0;
for i = 1:length(eigsA)
    if(eigsA(i)>0)
        flag_unstable = 1;
    end
    if(eigsA(i) == 0)
        flag_critical = 1;
    end
end

if(flag_unstable+flag_critical>0)
    if(flag_unstable==1)
        cprintf('SystemCommands','*****************************************\n');
        cprintf('-Red',          'THE SYSTEM HAS UNSTABLE POLES ! ! ! ! ! !\n');
        cprintf('SystemCommands','*****************************************\n');
    else
        cprintf('SystemCommands','*****************************************\n');
        cprintf('Black',         'THE SYSTEM HAS CRITCALLY STABLE POLES ! !\n');
        cprintf('SystemCommands','*****************************************\n');
    end
else
    % SYSTEM IS STABLE
end


% no balancing eigenvalues
[V,D] = eig(Amatrix,'nobalance');
[U,S,Vs] = svd(Amatrix);

StabTest.eigen.values = eigsA;
StabTest.eigen.V = V;
StabTest.eigen.D = D;

StabTest.singular.S = S;
StabTest.singular.U = U;
StabTest.singular.V = Vs;

[rA,cA] = size(Amatrix);
[rB,cB] = size(Bmatrix);

% generalized eigenvalues (if A,B square)
if((rA==cA)&&(rA==rB)&&(rB==cB))
    StabTest.genEigen  = eig(Amatrix,Bmatrix);
else
    StabTest.genEigen = [];
end

end
    
    