function [coherences,coherencesMeans] = SIM_MISO_InputCrossCoherence(InputsArray,sample_time,options)
%   
%   Syntax:
%   coherences,coherencesMeans] = MISO_InputCrossCoherence(InputsArray,sample_time,options)
%
%   Inputs:
%   InputsArray     : Array with Time at the 1st column and all inputs at
%   the following columns
%   sample_time     : sampling time
%   options         : Structure that contains the following:
%   options.Detrend : == 1 detrends the data
%   options.Window  : Windowing function and number of samples to
%                     use for each section
%   options.Noverlap: Number of samples by which the sections overlap
%   options.NFFT    : FT length which determines the frequencies at which 
%                     the coherence is estimated
%   options.ChirpZ  : ==1 if you want to do Chirp-Z based analysis
%   options.f1      : Lower Bound of Chirp-Z Frequency Zoom
%   options.f2      : Upper Bound of Chirp-Z Frequency Zoom
%   options.m       : Scalar that specifies the length of Chirp-Z Transform
%
%   Outputs:
%   coherences      : Input Cross Coherences between all inputs and the 
%   specified output
%   coherencesMeans : Input Cross CoherencesMean values of the coherences 
%   between all inputs and the specified output. 
%   
%   This Functions aims to aid the user to understand the cross-correlation
%   between the primary and the secondary inputs.
%
%   Authors:    Kostas Alexis (konstantinos.alexis@mavt.ethz.ch)
%

options.dB = 1;
options.plot = 0;
[N_i,M_i] = size(InputsArray);
M_i = M_i-1; 
Fs = 1/sample_time;

if(isfield(options,'detrend'))
    if(options.detrend == 1)
        for j = (1+1):(M_i+1)
            InputsArray_F(:,j) = detrend(InputsArray(:,j));
        end
    else
        for j = (1+1):(M_i+1)
            InputsArray_F(:,j) = InputsArray(:,j);
        end
    end
else
    for j = (1+1):(M_i+1)
        InputsArray_F(:,j) = InputsArray(:,j);
    end
end

for j = (1+1):(M_i+1)  
    for k = (1+1):(M_i+1)
        if(j~=k)
            coherences{j-1}{k-1} =  mscohere(InputsArray_F(:,j),InputsArray_F(:,k),options.Window,options.Noverlap,options.NFFT,Fs);
            coherencesMeans{j-1}{k-1} = sum(coherences{j-1}{k-1})/length(coherences{j-1}{k-1});
            figure
            cprintf('Black','Coherence between input %f',j-1);
            cprintf('Black',' and input %f \n',k-1);
            mscohere(InputsArray_F(:,j),InputsArray_F(:,k),options.Window,options.Noverlap,options.NFFT,Fs);
            cprintf('SystemCommands','Press any key to check next coherence (if any)\n');
            pause;
        end
    end
end

clf_flag = input('Press ~=0 to close all figures');
if(clf_flag~=0)
    close all
end

end




